Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

`Unreleased <../../compare/0.1...HEAD>`_
----------------------------------------

Nothing yet


`0.1 <../../releases/tag/0.1>`_ - 2021-12-22
--------------------------------------------

Initial release
